#
# spec file for package eza
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           eza
Version:        0.12.0~0
Release:        1.1
Summary:        Replacement for ls written in Rust
License:        MIT
Group:          System/Base
URL:            https://github.com/eza-community/eza
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
Source2:        cargo_config
BuildRequires:  bash-completion
BuildRequires:  cargo-packaging
BuildRequires:  fish
BuildRequires:  zsh
%ifnarch %ix86 %arm ppc
BuildRequires:  pandoc
%endif
Provides:       exa = 0.10.1
Obsoletes:      exa <= 0.10.1

%description
eza is a modern, maintained replacement for ls, built on exa.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%package fish-completion
Summary:        Fish completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%prep
%autosetup -a1
install -D -m 644 %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
%{cargo_install}

# Manpage
# pandoc isnt available everywhere
%ifnarch %ix86 %arm ppc
install -d -m 0755 %{buildroot}%{_mandir}/man1/
pandoc --standalone -f markdown -t man man/eza.1.md > %{buildroot}%{_mandir}/man1/eza.1

install -d -m 0755 %{buildroot}%{_mandir}/man5/
pandoc --standalone -f markdown -t man man/eza_colors.5.md > %{buildroot}%{_mandir}/man5/eza_colors.5
pandoc --standalone -f markdown -t man man/eza_colors-explanation.5.md > %{buildroot}%{_mandir}/man5/eza_colors-explanation.5
%endif

# Completion files
install -Dm0644 completions/bash/eza "%{buildroot}%{_datadir}/bash-completion/completions/%{name}"
install -Dm0644 completions/zsh/_eza "%{buildroot}%{_datadir}/zsh/site-functions/_%{name}"
install -Dm0644 completions/fish/eza.fish "%{buildroot}/%{_datadir}/fish/vendor_completions.d/%{name}.fish"

%check
%{cargo_test}

%files
%license LICENCE
%doc README.md
%{_bindir}/eza
%ifnarch %ix86 %arm ppc
%{_mandir}/man1/eza.1%{?ext_man}
%{_mandir}/man5/eza_colors.5%{?ext_man}
%{_mandir}/man5/eza_colors-explanation.5%{?ext_man}
%endif

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%files zsh-completion
%{_datadir}/zsh/site-functions/_%{name}

%files fish-completion
%{_datadir}/fish/vendor_completions.d/%{name}.fish

%changelog
* Fri Sep 15 2023 Michael Vetter <mvetter@suse.com>
- Add version to provides/obsoletes
* Fri Sep 15 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.12.0:
  Bug Fixes:
  * Expand --all help
  * RUSTSEC-2020-0071
  * Generalize gitignore to ignore all eza deb packages
  * Canonicalize errors when the destination of a symbolic link is bad
  * Handle other canonicalize errors in hyperlinks and git
  * Fix windows build when canonicalize returns an error
  * Change trycmd config to use test/itest folder for testing
  * Revert to old apt install command suggestion and add hint
  * Remove stray backslashes
  * Is_some_and is an unstable Rust feature until 1.70
  * Revert "Support for Windows Hidden Files"
  * Shellcheck warnings
  * Revert "Support for Windows Hidden Files"
  * Shellcheck warnings
  * Exit 13 on os error 13
  * Rewrite comment
  * Improve trace strings
  * Tracing typo
  Documentation:
  * Expand --all documentation
  * Add pthorpe92 gist
  * Remove xtests section from readme
  * Add deprecation warning to xtests/readme
  * Add deprecation warning to just xtest commands
  * Add deprecation warning to vagrantfile
  * Add MacPorts install info
  * Add gentoo
  * Fix gentoo install
  * Add docs for --git-repos & --git-repos-no-status
  * Fix gpg armor flag for deb release in readme
  * Add better explanation of git repos + no status
  * Add scoop install info
  * Remove color specifications. change unknown git repo status to ~
  * Fix missing color specification from man page
  Features
  * Add audit workflow
  * Add trycmd as dev-dependency
  * Add minimal trycmd binary
  * Add a few trycmd tests as example
  * Document and change output for --git-repos
  * Add apt installation workflow
  * Adds filtering on Windows hidden files
  * Adds filtering on Windows hidden files
  * Adds filtering on Windows hidden files
  * Added shellcheck to treefmt
  * Adds filtering on Windows hidden files
  * Add PERMISSION_DENIED exit code
* Mon Sep 11 2023 Michael Vetter <mvetter@suse.com>
- Add Provides/Obsoletes exa
  Since exa seems not maintained and eza wants to continue
  its work
* Mon Sep 11 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.11.1:
  Bug Fixes:
  * Add vendored-libgit2 feature to git2 dependency
  * Filename escaping (last character lost sometimes, no hyperlink)
  * Build for Windows with chrono
  Documentation:
  * Explain vendored-libgit2
  * Add homebrew, misc fixes
  * Fix code of conduct link
  * Update archlinux
  * Add star history
  * Add informaton about lazy_static
  * Remove broken dependabot link
  * Add bright color options in man pages
  * Add bright color support in readme changelog
  Features:
  * Add highlighting of mounted directories (Linux only)
  * Add backlog of icons from various exa pull requests and others
  * Mark .git as ignored, which hides it when using --git-ignore
  * Add backlog of icons from various exa issues
  * Expose git2 feature vendored-libgit2
  * Add build commands to deb-package.sh
  * Support the MSRV of Rust (1.65.0)
  * Add bright colour options, change punctuation default
  * Use chrono crate to handle datetime-related features
* Thu Sep  7 2023 Michael Vetter <mvetter@suse.com>
- Initial package for eza 0.11.0 for openSUSE
